/* This is the main window for our precision test.
 * It inherits from the QMainDialog class.
 * 
 * concept and design: Petr Felkel - felkepet@fel.cvut.cz
 *
 * programming: Petr Felkel   - felkepet@fel.cvut.cz
 *				Lukas Novosad - novosluk@fel.cvut.cz
 *
 * date: 21.10.2010
 *
 */

#ifndef EXERCISE_3_H
#define EXERCISE_3_H

// Qt includes
#include <QtGui/QMainWindow>
#include <QtGui/QInputDialog>
#include "ui_exercise_3.h"

#include "aboutdialog.h"
#include "drawareawidget.h"


class exercise_3 : public QMainWindow
{
	Q_OBJECT

public:

	exercise_3(QWidget *parent = 0, Qt::WFlags flags = 0);
	~exercise_3();

	AboutDialog aboutDialog;
	DrawAreaWidget drawArea; // the widget where we draw the points and the convex hull

private:

	Ui::exercise_3Class ui;

	// labels used for the status bar
	QLabel *numberOfPointsLabel;
	QLabel *numberOfPointsValueLabel;
	QLabel *pointGeneratorLabel;
	QLabel *pointGeneratorValueLabel;
	QLabel *chAlgorithmLabel;
	QLabel *chAlgorithmValueLabel;
	QLabel *timeMeasurementLabel;
	QLabel *timeMeasurementValueLabel;

public slots:

	void createAboutDialog();

	// slots to select the point generator
	void setPointGeneratorOnDisc();
	void setPointGeneratorOnCircle();
	void setPointGeneratorInSquare();
	void setPointGeneratorOnSquare();
	void setPointGeneratorInRectangle();
	void setPointGeneratorOnSegment();

	// slots to select the CH algorithm
	void setChAlg_AKL();
	void setChAlg_BYKAT();
	void setChAlg_EDDY();
	void setChAlg_GRAHAM_ANDREW();
	void setChAlg_JARVIS();
	void setChAlg_MY_GRAHAM();
	void setChAlg_MY_JARVIS();
	void setChAlg_MY_CHAN();

	// slots to select the number of points
	void setNumOfPoints10();
	void setNumOfPoints100();
	void setNumOfPoints1000();
	void setNumOfPoints10000();
	void setNumOfPoints100000();
	void setNumOfPoints1000000();
	void setNumOfPoints10000000();

	// slots to update the labels on the status bar
	void setNumberOfPointsValueLabel(long numberOfPoints);
	void setPointGeneratorValueLabel(PointGenerator pointGenerator);
	void setChAlgorithmValueLabel(ChAlgorithm chAlgorithm);
	void setTimeMeasurementValueLabel(QString timeMeasurement);
	

signals:

	// signals for the status bar updates
	void pointGeneratorChanged(PointGenerator pointGenerator);
	void chAlgorithmChanged(ChAlgorithm chAlgorithm);
	void numOfPointsChanged(long numberOfPoints);

};

#endif // EXERCISE_3_H
